<?php

namespace Drupal\config_enforce_devel;

/**
 * Provides integration with config_devel.
 */
class ConfigDevelHelper {

  /**
   * Provide Config Devel module with configs to read from disk.
   *
   * @see hook_config_devel_auto_import()
   */
  public static function autoImport() {
    $auto_import = [];
    foreach ((new EnforcedConfigCollection())->getEnforcedConfigs() as $config_name => $setting) {
      $auto_import[$config_name] = [
        'filename' => $setting['config_file_path'],
        'hash' => isset($setting['hash']) ? $setting['hash'] : '',
      ];
    }
    return $auto_import;
  }

  /**
   * Provide Config Devel module with config files to write to disk.
   *
   * @see hook_config_devel_auto_export()
   */
  public static function autoExport() {
    $auto_export = [];
    foreach ((new EnforcedConfigCollection())->getEnforcedConfigs() as $config_name => $settings) {
      $auto_export[] = $settings['config_file_path'];
    }
    return $auto_export;
  }

  /**
   * Save hashes of auto-imported config files.
   *
   * @see config_enforce_devel_config_devel_post_auto_import()
   */
  public static function postAutoImport(array $auto_import) {
    $hashes = [];
    foreach ($auto_import as $config_name => $results) {
      $hashes[$config_name] = ['hash' => $results['hash']];
    }
    (new EnforcedConfigCollection())->updateEnforcedConfigs($hashes);
  }

}
